@@ -1,11 +1,17 @@
+import os
 import numpy as np
 from math import pi
+from sys import platform
+import time
+
 import glimy.geo1D
 import glimy.geo2D
 import glimy.geo3D
 import glimy.curved
+
 import matplotlib.pyplot as plt
 
+
 G=6.6743e-11
 c=299792458
 c_2=c**2
@@ -69,14 +75,14 @@ class Continuum(object):
                 if self.__dim==1 and not isinstance(arg, (geo1D.Line, geo1D.VLine)):
                     raise TypeError("In 1-D, only lines are allowed")
                 
-                elif self.__dim==2 and not isinstance(arg, (geo2D.Rectangle, geo2D.Circle, geo2D.VRectangle)):
+                elif self.__dim==2 and not isinstance(arg, (geo2D.PointCloud,geo2D.Rectangle, geo2D.Circle, geo2D.VRectangle)):
                     raise TypeError("In 2-D, only defined geometries are allowed")
                 
-                elif self.__dim==3 and not isinstance(arg, (geo3D.RectPrism, geo3D.Cylinder, geo3D.Sphere, geo3D.VRectPrism)):
+                elif self.__dim==3 and not isinstance(arg, (geo3D.PointCloud, geo3D.RectPrism, geo3D.Cylinder, geo3D.Sphere, geo3D.VRectPrism)):
                     raise TypeError("In 3-D, only defined geometries are allowed")
                 
                 else:
-                    if isinstance(arg,(geo1D.Line, geo2D.Rectangle, geo2D.Circle, geo3D.RectPrism, geo3D.Cylinder, geo3D.Sphere)):
+                    if isinstance(arg,(geo1D.Line, geo2D.PointCloud, geo2D.Rectangle, geo2D.Circle, geo3D.PointCloud, geo3D.RectPrism, geo3D.Cylinder, geo3D.Sphere)):
                         self.__geometries.append(arg)
                         self.__n_of_objects+=1
                     else:
@@ -475,10 +481,10 @@ def Render(field, n_time_steps,pre=False):
                 if source[0]==0 and source[2][0]<=t<=source[2][1]:
                     E[2][source[1]]+=source[3]*np.sin(source[4]*t+source[5])
         
-        field.load_from_renderer(E, H)
+        field.load_from_renderer(E, H, E_mul, H_mul)
 
-                    
-        
+def CppRender(field, n_time_steps,pre=False):               
+        pass
 
 class DotSource(object):
     def __init__(self, location, presence ,amplitude, frequency, phase=0):
@@ -500,4 +506,3 @@ class DotSource(object):
     @property
     def inf(self):
         return [0, self.__location, self.__presence, self.__amplitude, self.__frequency, self.__phase]
-
